@@ -20,16 +20,16 @@
 #define ECBUILD_VERSION "3.6.4"
 #endif
 #ifndef ECBUILD_MACROS_DIR
-#define ECBUILD_MACROS_DIR  "D:/bld/eccodes_1638916851819/work/cmake"
+#define ECBUILD_MACROS_DIR  "D:/bld/eccodes_1641825434186/work/cmake"
 #endif
 
 /* config info */
 
-#define ECCODES_OS_NAME          "Windows-10.0.14393"
+#define ECCODES_OS_NAME          "Windows-10.0.17763"
 #define ECCODES_OS_BITS          64
 #define ECCODES_OS_BITS_STR      "64"
 #define ECCODES_OS_STR           "windows.64"
-#define ECCODES_OS_VERSION       "10.0.14393"
+#define ECCODES_OS_VERSION       "10.0.17763"
 #define ECCODES_SYS_PROCESSOR    "AMD64"
 
 #define ECCODES_BUILD_TIMESTAMP  ""
@@ -41,7 +41,7 @@
 #define ECCODES_CXX_COMPILER_ID      ""
 #define ECCODES_CXX_COMPILER_VERSION ""
 
-#define ECCODES_C_COMPILER       "C:/Program Files (x86)/Microsoft Visual Studio/2017/Enterprise/VC/Tools/MSVC/14.16.27023/bin/Hostx64/x64/cl.exe"
+#define ECCODES_C_COMPILER       "C:/Program Files (x86)/Microsoft Visual Studio/2019/Enterprise/VC/Tools/MSVC/14.16.27023/bin/HostX64/x64/cl.exe"
 #define ECCODES_C_FLAGS          "/DWIN32 /D_WINDOWS /W3 /D_CRT_SECURE_NO_WARNINGS /D_CRT_NONSTDC_NO_DEPRECATE /wd4267 /MD /O2 /Ob2 /DNDEBUG"
 
 #define ECCODES_CXX_COMPILER     ""
@@ -49,13 +49,13 @@
 
 /* Needed for finding per package config files */
 
-#define ECCODES_INSTALL_DIR       "D:/bld/eccodes_1638916851819/_h_env/Library"
-#define ECCODES_INSTALL_BIN_DIR   "D:/bld/eccodes_1638916851819/_h_env/Library/bin"
-#define ECCODES_INSTALL_LIB_DIR   "D:/bld/eccodes_1638916851819/_h_env/Library/lib"
-#define ECCODES_INSTALL_DATA_DIR  "D:/bld/eccodes_1638916851819/_h_env/Library/share/eccodes"
+#define ECCODES_INSTALL_DIR       "D:/bld/eccodes_1641825434186/_h_env/Library"
+#define ECCODES_INSTALL_BIN_DIR   "D:/bld/eccodes_1641825434186/_h_env/Library/bin"
+#define ECCODES_INSTALL_LIB_DIR   "D:/bld/eccodes_1641825434186/_h_env/Library/lib"
+#define ECCODES_INSTALL_DATA_DIR  "D:/bld/eccodes_1641825434186/_h_env/Library/share/eccodes"
 
-#define ECCODES_DEVELOPER_SRC_DIR "D:/bld/eccodes_1638916851819/work"
-#define ECCODES_DEVELOPER_BIN_DIR "D:/bld/eccodes_1638916851819/work/build"
+#define ECCODES_DEVELOPER_SRC_DIR "D:/bld/eccodes_1641825434186/work"
+#define ECCODES_DEVELOPER_BIN_DIR "D:/bld/eccodes_1641825434186/work/build"
 
 /* Fortran support */
 
